==> zircon-1.18.143.tar.gz: zircon-1.18.143/lib/userCmds.tcl <==
#
# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/userCmds.tcl,v $
# $Date: 1998/04/30 13:17:58 $
# $Revision: 1.18.1.12 $
#
package provide zircon 1.18
#
#	Users cmds
#
proc doInvite {net nk chan} {
    switch {} $nk return
    switch {} $chan return
    $net configure -lastuser $nk
    $net INVITE $nk $chan
}

proc userInvite {net chan} {
    set lu [$net lastuser]
    mkEntryBox .@inv$net [trans invite] {Enter user and channel:} \
      [list [list user $lu] [list channel $chan]] \
      [list ok "doInvite $net"] [list cancel {}]
}
#
proc doMsg {net nk} {
    switch {} $nk return
    Message :: make $net $nk
    $net configure -lastuser $nk
}
#
proc userMessage {net} {
    mkEntryBox .@msg$net [trans message] {Enter user name:} \
      [list [list user [$net lastuser]]] \
      [list ok "doMsg $net"] [list cancel {}]
}
#
proc doFing {net nk} {
    switch {} $nk return
    $net configure -lastuser $nk
    finger $net $nk
} 
#
proc userFinger {net} {
    mkEntryBox .@fng$net [trans finger] {Enter user name:} \
      [list [list user [$net lastuser]]] \
      [list ok "doFing $net"] [list cancel {}]
}
#
proc userNotice {net} {
    mkEntryBox .@not$net [trans notice] {Enter user name and notice text:} \
      [list [list user [$net lastuser]] [list notice {}]] \
      [list ok "doNet $net NOTICE"] [list cancel {}]
}
#
proc doNet {net cmd nk op} {
    switch {} $nk return
    $net configure -lastuser $nk
    $net $cmd $nk $op
}
#
proc userWhois {net} {
    mkEntryBox .@wis$net [trans whois] {Enter user name and server:} \
      [list [list user [$net lastuser]] [list Where {}]] \
      [list ok "doNet $net WHOIS"] [list cancel {}]
}
#
proc userWhowas {net} {
    mkEntryBox .@was$net [trans whowas] {Enter user name and count:} \
      [list [list user [$net lastuser]] [list Count {}]] \
      [list ok "doNet $net WHOWAS"] [list cancel {}]
}
#
proc doUMode {net nk mode} {
    if {![string match {} $nk] && [string match {[+-]*} mode]} {
	$net configure -lastuser $Nk
	$net q1Send "MODE $nk :$mode"
    }
}
#
proc userMode {net} {
    mkEntryBox .@umd$net {User Mode} {Enter user and mode:} \
      [list [list user [$net lastuser]] [list mode {}]] \
      [list ok "doUMode $net"] [list cancel {}]
}
#
proc userCmd {net cmd args} {
    switch -exact -- $cmd {
    Mode { userMode $net}
    Finger {userFinger $net}
    Invite { userInvite $net {} }
    Message {userMessage $net}
    Notice {userNotice $net}
    Kill {userKill $net}
    Whois {userWhois $net}
    Whowas {userWhowas $net}
    default {
	    mkEntryBox .@$cmd$net [trans $cmd] {Enter user pattern:} \
	      [list [list user [$net lastuser]]] \
	      [list ok "uSend $net [string toupper $cmd]"] [list cancel {}]
	}
    }
}
#
proc uSend {net cmd nk} {
    switch {} $nk return
    $net configure -lastuser $nk
    $net q1Send "$cmd :$nk"
}

==> zircon_1.18.187.orig.tar.gz: zircon-1.18.187.orig/lib/userCmds.tcl <==
#
# $Source: /home/nlfm/Zircon/lib/RCS/userCmds.tcl,v $
# $Date: 1998/07/14 09:32:31 $
# $Revision: 1.18.1.13 $
#
package provide zircon 1.18
#
#	Users cmds
#
proc doInvite {net nk chan} {
    switch {} $nk return
    switch {} $chan return
    $net configure -lastuser $nk
    $net INVITE $nk $chan
}

proc userInvite {net chan} {
    set lu [$net lastuser]
    mkEntryBox .@inv$net [trans invite] {Enter user and channel:} \
      [list [list user $lu] [list channel $chan]] \
      [list ok "doInvite $net"] [list cancel {}]
}
#
proc doMsg {net nk} {
    switch {} $nk return
    Message :: make $net $nk
    $net configure -lastuser $nk
}
#
proc userMessage {net} {
    mkEntryBox .@msg$net [trans message] {Enter user name:} \
      [list [list user [$net lastuser]]] \
      [list ok "doMsg $net"] [list cancel {}]
}
#
proc doFing {net nk} {
    switch {} $nk return
    $net configure -lastuser $nk
    finger $net $nk
} 
#
proc userFinger {net} {
    mkEntryBox .@fng$net [trans finger] {Enter user name:} \
      [list [list user [$net lastuser]]] \
      [list ok "doFing $net"] [list cancel {}]
}
#
proc userNotice {net} {
    mkEntryBox .@not$net [trans notice] {Enter user name and notice text:} \
      [list [list user [$net lastuser]] [list notice {}]] \
      [list ok "doNet $net NOTICE"] [list cancel {}]
}
#
proc lastWho {net} {
    switch {} [set lw [$net lastwho]] {
        set lw [$net lastuser]
    }
    return $lw
}
#
proc doNet {net cmd nk op} {
    switch {} $nk return
    $net configure -lastwho $nk
    $net $cmd $nk $op
}
#
proc doNet1 {net cmd nk} {
    switch {} $nk return
    $net configure -lastwho $nk
    $net $cmd $nk
}
#
proc userWho {net} {
    mkEntryBox .@wq$net [trans who] {Enter user name} \
      [list [list user [lastWho $net]]] \
      [list ok "doNet1 $net WHO"] [list cancel {}]
}
#
proc userWhois {net} {
    mkEntryBox .@wis$net [trans whois] {Enter user name and server:} \
      [list [list user [lastWho $net]] [list Where {}]] \
      [list ok "doNet $net WHOIS"] [list cancel {}]
}
#
proc userWhowas {net} {
    mkEntryBox .@was$net [trans whowas] {Enter user name and count:} \
      [list [list user [lastWho $net]] [list Count {}]] \
      [list ok "doNet $net WHOWAS"] [list cancel {}]
}
#
proc doUMode {net nk mode} {
    if {![string match {} $nk] && [string match {[+-]*} mode]} {
	$net configure -lastuser $Nk
	$net q1Send "MODE $nk :$mode"
    }
}
#
proc userMode {net} {
    mkEntryBox .@umd$net {User Mode} {Enter user and mode:} \
      [list [list user [$net lastuser]] [list mode {}]] \
      [list ok "doUMode $net"] [list cancel {}]
}
#
proc userCmd {net cmd args} {
    switch -exact -- $cmd {
    Mode	{userMode $net}
    Finger	{userFinger $net}
    Invite	{userInvite $net {}}
    Message	{userMessage $net}
    Notice	{userNotice $net}
    Kill	{userKill $net}
    Who		{userWho $net}
    Whois	{userWhois $net}
    Whowas	{userWhowas $net}
    default {
	    mkEntryBox .@$cmd$net [trans $cmd] {Enter user pattern:} \
	      [list [list user [$net lastuser]]] \
	      [list ok "uSend $net [string toupper $cmd]"] [list cancel {}]
	}
    }
}
#
proc uSend {net cmd nk} {
    switch {} $nk return
    $net configure -lastuser $nk
    $net q1Send "$cmd :$nk"
}
